@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute the affinity between two people
 
-our $VERSION = '0.0107';
+our $VERSION = '0.0108';
 
 use Moo;
 use strictures 2;
@@ -100,7 +100,7 @@ Acme::Affinity - Compute the affinity between two people
 
 =head1 VERSION
 
-version 0.0107
+version 0.0108
 
 =head1 SYNOPSIS
 
@@ -144,7 +144,7 @@ Default:
 =head2 me
 
 An array reference triple of question responses, desired responses and
-importance levels for person A.
+importance levels of person A for each of the given B<questions>.
 
 Example:
 
@@ -155,7 +155,7 @@ Example:
 =head2 you
 
 An array reference triple of question responses, desired responses and
-importance levels for person B.
+importance levels of person B for each of the given B<questions>.
 
 Example:
 
@@ -179,6 +179,8 @@ Compute the affinity score for the two given people.
 
 =head1 SEE ALSO
 
+The F<eg/*> and F<t/01-methods.t> programs in this distribution.
+
 L<Moo>
 
 L<Math::BigRat>
